@@ -1,7 +1,8 @@
 from ..account import OPAccount
 from ..op_items._item_list import OPItemList
 from ..op_items._new_field_registry import OPNewItemField
-from ..op_items._new_fields import (
+from ..op_items._new_item import OPNewSection
+from ..op_items.fields_sections._new_fields import (
     OPNewConcealedField,
     OPNewPasswordField,
     OPNewStringField,
@@ -9,26 +10,36 @@ from ..op_items._new_fields import (
     OPNewTOTPUri,
     OPNewUsernameField
 )
-from ..op_items._new_item import OPNewSection
-from ..op_items._op_items_base import OPAbstractItem
-from ..op_items.api_credential import OPAPICredentialItem
-from ..op_items.credit_card import OPCreditCardItem
-from ..op_items.document import OPDocumentFile, OPDocumentItem
-from ..op_items.item_field import OPConcealedField, OPStringField, OPTOTPField
-from ..op_items.item_field_base import OPItemField
-from ..op_items.item_section import OPSection
-from ..op_items.login import (
+from ..op_items.fields_sections.item_field import (
+    OPConcealedField,
+    OPStringField,
+    OPTOTPField
+)
+from ..op_items.fields_sections.item_field_base import OPItemField
+from ..op_items.fields_sections.item_section import OPSection
+from ..op_items.item_types._item_base import OPAbstractItem
+from ..op_items.item_types.api_credential import OPAPICredentialItem
+from ..op_items.item_types.credit_card import OPCreditCardItem
+from ..op_items.item_types.database import (
+    OPDatabaseItem,
+    OPDatabaseItemRelaxedValidation
+)
+from ..op_items.item_types.document import OPDocumentFile, OPDocumentItem
+from ..op_items.item_types.login import (
     OPLoginItem,
     OPLoginItemNewPrimaryURL,
     OPLoginItemNewURL,
     OPLoginItemRelaxedValidation,
     OPLoginItemTemplate
 )
-from ..op_items.password import OPPasswordItem
+from ..op_items.item_types.password import OPPasswordItem
+from ..op_items.item_types.secure_note import OPSecureNoteItem
+from ..op_items.item_types.server import (
+    OPServerItem,
+    OPServerItemRelaxedValidation
+)
+from ..op_items.item_types.ssh_key import OPSSHKeyItem
 from ..op_items.password_recipe import OPPasswordRecipe
-from ..op_items.secure_note import OPSecureNoteItem
-from ..op_items.server import OPServerItem, OPServerItemRelaxedValidation
-from ..op_items.ssh_key import OPSSHKeyItem
 from ..op_items.totp import OPTOTPItem
 from ..op_objects import OPGroup, OPUser, OPVault
 
@@ -61,6 +72,8 @@ __all__ = [
     "OPLoginItemNewURL",
     "OPLoginItemRelaxedValidation",
     "OPLoginItemTemplate",
+    "OPDatabaseItem",
+    "OPDatabaseItemRelaxedValidation",
     "OPPasswordItem",
     "OPPasswordRecipe",
     "OPSecureNoteItem",
